const searchInput = document.querySelector(".input-search");
const prevButton = document.querySelector("#previous");
const nextButton = document.querySelector("#next");
const buttonSearch = document.querySelector(".search");
const pageNumber = document.querySelector("#page-number");
const pagesCount = document.querySelector("#pages");
const pageText = document.querySelector("#pagination-text");
const albumResult = document.querySelector(".album-wrapper");
const pagination = document.querySelector(".pagination");
const albums = document.querySelectorAll(".album");
const sortInput = document.querySelector(".sort-select");
const orderInput = document.querySelector(".order-select");
const creatorInput = document.querySelector(".creator-select");

const debounce = (func, delay) => {
    let timer;
    return (...args) => {
        clearTimeout(timer);
        timer = setTimeout(() => {
            func.apply(this, args);
        }, delay);
    };
};

let currentPage = 1;
let limit = 6;

searchInput &&
searchInput.addEventListener("keyup", 
    debounce(
        async (e) => {
            currentPage = 1;
            e.preventDefault();
            window.history.pushState(
                "",
                "",
                `/album-list?q=${searchInput.value}&sort=${sortInput.value}&order=${orderInput.value}&creator=${creatorInput.value}`
            );
            const xhr = new XMLHttpRequest();
            xhr.open(
                "GET",
                `/album/fetch/?csrf_token=${CSRF_TOKEN}&q=${searchInput.value}&sort=${sortInput.value}&order=${orderInput.value}&creator=${creatorInput.value}`
            );

            xhr.send();

            xhr.onreadystatechange = function () {
                if (this.readyState === XMLHttpRequest.DONE) {
                    data = JSON.parse(this.responseText);
                    console.log(data);
                    updateData(data);
                }
            };
            
        },
        500
    ));

buttonSearch &&
    buttonSearch.addEventListener("submit", async (e) => {
        currentPage = 1;
        e.preventDefault();
        window.history.pushState(
            "",
            "",
            `/album-list?q=${searchInput.value}&sort=${sortInput.value}&order=${orderInput.value}&creator=${creatorInput.value}`
        );
        const xhr = new XMLHttpRequest();
        xhr.open(
            "GET",
            `/album/fetch/?csrf_token=${CSRF_TOKEN}&q=${searchInput.value}&sort=${sortInput.value}&order=${orderInput.value}&creator=${creatorInput.value}`
        );

        xhr.send();

        xhr.onreadystatechange = function () {
            if (this.readyState === XMLHttpRequest.DONE) {
                data = JSON.parse(this.responseText);
                console.log(data);
                updateData(data);
            }
        };
    });


const updateData = (data) => {
    let newHTML = "";
    data.albums.map((album) => {
        newHTML += `
        <div class="album" id="${album.album_id}" >
            <img src="presentation/music/info/img/defalbum.jpg" alt="Playlist 1">
            <h3>${album.name}</h3>
            <p>By : ${album.username}</p>
            <p>Released : ${album.year}</p>
            <p>ID : ${album.album_id}</p>
        </div>
        `;
    });
    albumResult.innerHTML = newHTML;
    albumResult.addEventListener("click", function (e) {
        const clickedElement = e.target;
        const albumElement = clickedElement.closest(".album");
        if (albumElement) {
            const albumId = albumElement.id;
            // Redirect
            window.location.href = `/album?id=${albumId}`;
        }
    });
    
    pageNumber.innerHTML = currentPage;
    if (currentPage == 1) {
        prevButton.disabled = true;
    } else {
        prevButton.disabled = false;
    }

    if (currentPage == pagesCount.innerHTML) {
        nextButton.disabled = true;
    } else {
        nextButton.disabled = false;
    }
};


albums.forEach((album) => {
    album.addEventListener("click", async (e) => {
        e.preventDefault();

        // Redirect to album page
        window.location.href = `/album?id=${album.id}`;
    });
});
